from .options import get_full_options, get_db_powder, get_powder_names, get_options_sample, get_options_agard, get_options_sample_2
from .termo import ozvb_termo
from .lagrange import ozvb_lagrange

__version__ = '1.1.2'


from pytest import approx
from pyballistics import get_powder_names, get_options_sample, get_full_options

def test_get_options_sample():
    res = get_options_sample()
    assert res is not None

def test_full_opts():
    res = get_full_options(get_options_sample())
    assert res is not None

def test_get_powder_names():
    res = get_powder_names()
    assert res


from pytest import approx
from pyballistics import ozvb_termo, get_options_sample, ozvb_lagrange



def test_ozvb_termo():
    opts = get_options_sample()
    res = ozvb_termo(opts)
    assert res['stop_reason'] != 'error'

def test_ozvb_lagrange():
    opts = get_options_sample()
    res = ozvb_lagrange(opts)
    assert res['stop_reason'] != 'error'
